@@ -533,7 +533,7 @@ impl<'a> Emitter<'a> {
         match *n.expr {
             Expr::Member(ref e) => {
                 emit!(e.obj);
-                self.wr.write_operator("?.")?;
+                punct!("?.");
 
                 if e.computed {
                     punct!("[");
@@ -545,7 +545,7 @@ impl<'a> Emitter<'a> {
             }
             Expr::Call(ref e) => {
                 emit!(e.callee);
-                self.wr.write_operator("?.")?;
+                punct!("?.");
 
                 punct!("(");
                 self.emit_expr_or_spreads(n.span(), &e.args, ListFormat::CallExpressionArguments)?;
@@ -577,7 +577,10 @@ impl<'a> Emitter<'a> {
     fn emit_new_expr(&mut self, node: &NewExpr) -> Result {
         self.emit_leading_comments_of_span(node.span(), false)?;
 
-        keyword!("new");
+        {
+            let span = self.cm.span_until_char(node.span, ' ');
+            keyword!(span, "new");
+        }
         space!();
         emit!(node.callee);
 
@@ -1507,7 +1510,7 @@ impl<'a> Emitter<'a> {
         }
 
         if format.contains(ListFormat::BracketsMask) {
-            self.wr.write_punct(format.opening_bracket())?;
+            self.wr.write_punct(None, format.opening_bracket())?;
 
             if is_empty {
                 self.emit_trailing_comments_of_pos(
@@ -1647,7 +1650,7 @@ impl<'a> Emitter<'a> {
             };
 
             if has_trailing_comma && format.contains(ListFormat::CommaDelimited) {
-                self.wr.write_punct(",")?;
+                punct!(self, ",");
                 formatting_space!(self);
             }
 
@@ -1708,7 +1711,7 @@ impl<'a> Emitter<'a> {
                     true,
                 )?; // Emit leading comments within empty lists
             }
-            self.wr.write_punct(format.closing_bracket())?;
+            self.wr.write_punct(None, format.closing_bracket())?;
         }
 
         Ok(())
@@ -1925,7 +1928,14 @@ impl<'a> Emitter<'a> {
     fn emit_block_stmt(&mut self, node: &BlockStmt) -> Result {
         self.emit_leading_comments_of_span(node.span(), false)?;
 
-        punct!("{");
+        {
+            let span = if node.span.is_dummy() {
+                DUMMY_SP
+            } else {
+                Span::new(node.span.lo, node.span.lo + BytePos(1), Default::default())
+            };
+            punct!(span, "{");
+        }
         self.emit_list(
             node.span(),
             Some(&node.stmts),
@@ -1934,7 +1944,14 @@ impl<'a> Emitter<'a> {
 
         self.emit_leading_comments_of_span(node.span(), true)?;
 
-        punct!("}");
+        {
+            let span = if node.span.is_dummy() {
+                DUMMY_SP
+            } else {
+                Span::new(node.span.hi - BytePos(1), node.span.hi, Default::default())
+            };
+            punct!(span, "}");
+        }
     }
 
     #[emitter]
@@ -2028,7 +2045,10 @@ impl<'a> Emitter<'a> {
     fn emit_if_stmt(&mut self, node: &IfStmt) -> Result {
         self.emit_leading_comments_of_span(node.span(), false)?;
 
-        keyword!("if");
+        {
+            let span = self.cm.span_until_char(node.span, ' ');
+            keyword!(span, "if");
+        }
 
         formatting_space!();
         punct!("(");
@@ -2126,7 +2146,9 @@ impl<'a> Emitter<'a> {
     fn emit_throw_stmt(&mut self, node: &ThrowStmt) -> Result {
         self.emit_leading_comments_of_span(node.span(), false)?;
 
-        keyword!("throw");
+        let throw_span = self.cm.span_until_char(node.span, ' ');
+
+        keyword!(throw_span, "throw");
         space!();
         emit!(node.arg);
         formatting_semi!();
@@ -2244,18 +2266,18 @@ impl<'a> Emitter<'a> {
     fn write_delim(&mut self, f: ListFormat) -> Result {
         match f & ListFormat::DelimitersMask {
             ListFormat::None => {}
-            ListFormat::CommaDelimited => self.wr.write_punct(",")?,
+            ListFormat::CommaDelimited => self.wr.write_punct(None, ",")?,
             ListFormat::BarDelimited => {
                 if !self.cfg.minify {
                     self.wr.write_space()?;
                 }
-                self.wr.write_punct("|")?;
+                self.wr.write_punct(None, "|")?;
             }
             ListFormat::AmpersandDelimited => {
                 if !self.cfg.minify {
                     self.wr.write_space()?;
                 }
-                self.wr.write_punct("&")?;
+                self.wr.write_punct(None, "&")?;
             }
             _ => unreachable!(),
         }
